@@ -6,5 +6,5 @@ using namespace Rcpp;
 // [[Rcpp::export]]
 double SGN_Cpp(const NumericVector& X) {
   int n = X.size();
-  return sqrt(n) * (mean((X) > 0) - 0.5);
+  return sqrt((double)n) * (mean((X) > 0) - 0.5);
 }
